<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use App\Models\CodeVoucherModel;
use App\Models\MetatagModel;
use App\Models\SettingModel;
use App\Models\GiftModel;
use Illuminate\Http\Request;

class PlayerController extends Controller
{

    function login()
    {
        if (!str_contains($_SERVER['SERVER_NAME'], "mystery-box") && $this->limitDomain) {
            return view('/welcome');
        }

        $title = "Selamat Datang di " . env('APP_NAME');

        $metatag = MetatagModel::where('id', 1)->first();

        $list = GiftModel::where('deleted_at', NULL)->orderBy('created_at')->get();

        $setting_list = SettingModel::all();

        foreach ($list as $key => $item) {
            $segments[] = [
                'id' => $item->id,
                'text' => $item->name,
                'name' => $item->name,
                'image' => $item->gift_image,
                'item_image' => $item->gift_image,
                'ordering' => $key,
                'created_at' => null,
                'value' => $item->gift
            ];
        }

        // dd($segments);
        shuffle($segments);

        foreach ($setting_list as $item) {
            $settings[$item->key] = $item->value;
            $settings[$item->key . "Default"] = $item->default_value;
        }

        $no =  (isset($settings["whatsapp"]) ? $settings["whatsapp"] : "601000000000");
        $settings['whatsapp'] = 'https://wa.me/' .  preg_replace("/[^a-zA-Z0-9\s!?.,\'\"]/", "", $no) . '?text=';

        return view('/pages/user/start', [
            'title' => $title,
            'metatag' => $metatag,
            'segments' => collect($segments),
            'settings' => $settings
        ]);
    }

    function room($code)
    {

        if (!str_contains($_SERVER['SERVER_NAME'], "mystery-box") && $this->limitDomain) {
            return view('/welcome');
        }

        $title = "Selamat Datang di " . env('APP_NAME');

        $metatag = MetatagModel::where('id', 1)->first();

        $checkCode = CodeVoucherModel::where('code', $code)->first();

        if ($checkCode != null) {

            if ($checkCode->date_used == null) {

                $list = GiftModel::where('deleted_at', NULL)->orderBy('created_at')->get();

                $setting_list = SettingModel::all();

                foreach ($list as $key => $item) {
                    $segments[] = [
                        'id' => $item->id,
                    ];
                }

                foreach ($setting_list as $item) {
                    $settings[$item->key] = $item->value;
                    $settings[$item->key . "Default"] = $item->default_value;
                }

                $no =  (isset($settings["whatsapp"]) ? $settings["whatsapp"] : "601000000000");
                $settings['whatsapp'] = 'https://wa.me/' .  preg_replace("/[^a-zA-Z0-9\s!?.,\'\"]/", "", $no) . '?text=';

                return view('/pages/user/index', [
                    'title' => $title,
                    'metatag' => $metatag,
                    'code' => $code,
                    'segments' => collect($segments),
                    'settings' => $settings
                ]);
            }
        }

        return redirect("/");
    }

    function check(Request $request)
    {

        if (!str_contains($_SERVER['SERVER_NAME'], "mystery-box") && $this->limitDomain) {
            return view('/welcome');
        }

        $setting_list = SettingModel::all();
        foreach ($setting_list as $item) {
            $settings[$item->key] = $item->value;
        }

        $no =  (isset($settings["whatsapp"]) ? $settings["whatsapp"] : "6282213017201");
        $whatsapp = 'https://wa.me/' .  preg_replace("/[^a-zA-Z0-9\s!?.,\'\"]/", "", $no) . '?text=Halo Admin,...';

        $input = $request->all();

        $checkCode = CodeVoucherModel::where('code', $input['code'])->first();

        $message = 'Kode yang Anda masukkan salah, silahkan hubungi Admin untuk mendapatkan kode tiket, <a class="text-warning" href="' . $whatsapp . '" target="_blank">disini</a>!';

        if ($checkCode != null) {

            $message = 'Kode yang Anda masukkan telah digunakan, silahkan hubungi Admin untuk mendapatkan kode tiket baru, <a class="text-warning" href="' . $whatsapp . '" target="_blank">disini</a>!';

            if ($checkCode->date_used == null) {

                return redirect("/play/" . $input['code']);
            }
        }

        return back()->with('error', $message);
    }

    function select(Request $request)
    {
        if (!str_contains($_SERVER['SERVER_NAME'], "mystery-box") && $this->limitDomain) {
            return response()->json([], 200);
        }

        $input = $request->all();

        $setting_list = SettingModel::all();
        foreach ($setting_list as $item) {
            $settings[$item->key] = $item->value;
        }

        $checkExist = CodeVoucherModel::where('code', $input['code'])->first();
        $gifts = GiftModel::where('deleted_at', NULL)->orderBy('created_at')->get();

        $no =  (isset($settings["whatsapp"]) ? $settings["whatsapp"] : "601162174675");
        $whatsapp = 'https://wa.me/' .  preg_replace("/[^a-zA-Z0-9\s!?.,\'\"]/", "", $no) . '?text=';

        if ($checkExist != NULL) {
            if ($checkExist->date_used == NULL) {

                foreach ($gifts as $key => $item) {
                    $probability =  $item->probabilty;

                    for ($i = 0; $i < $probability; $i++) {
                        $options[] = $key;
                    }
                }

                if ($checkExist->gift_name == NULL) {
                    $indexChoosen = $options[rand(0, (count($options) - 1))];
                } else {
                    foreach ($gifts as $key => $item) {
                        if ($item['name'] == $checkExist->gift_name) {
                            $indexChoosen = $key;
                        }
                    }
                }

                $isZonk = ($gifts[$indexChoosen]['zonk'] == 1);
                $gift_name = $gifts[$indexChoosen]['name'];

                $message = ($isZonk == true) ? ('Anda mendapatkan ' . $gift_name . '. Silahkan coba kembali!') : ('Selamat!!, Anda memenangkan ' . $gift_name . '. Silahkan anda Screenshot sebagai bukti kemenangan anda!');

                foreach ($gifts as $key => $item) {
                    $segments[] = [
                        'id' => $item->id,
                        'text' => $item->name,
                        'name' => $item->name,
                        'textFontSize' => $item->textFontSize,
                        'textFillStyle' => $item->text_color,
                        'textFontFamily' => $item->textFontFamily,
                        'image' => $item->gift_image,
                        'item_image' => $item->gift_image,
                        'ordering' => $key,
                        'created_at' => null,
                        'value' => $item->gift
                    ];
                }

                $selectedId = $input['id'];
                $previousSegments = $segments;

                // randomize/shuffle the prizes
                shuffle($segments);
                foreach ($segments as $key => $item) {
                    $segments[$key]['id'] = $previousSegments[$key]['id'];
                }

                foreach ($segments as $key => $item) {
                    if ($item['id'] == $selectedId) {
                        $segment_replaced = $gifts[$indexChoosen];
                        $segment_previous = $segments[$key];
                        $segments[$key] = $gifts[$indexChoosen];
                        $segments[$key]['item_image'] = $gifts[$indexChoosen]['gift_image'];
                        $segments[$key]['image'] = $gifts[$indexChoosen]['gift_image'];
                        $segments[$key]['id'] = $selectedId;
                    }
                }

                foreach ($segments as $key => $item) {
                    if ($item['name'] == $segment_replaced['name'] && $item['id'] != $segment_replaced['id']) {
                        $previousId = $item['id'];
                        $segments[$key] = $segment_previous;
                        $segments[$key]['id'] = $previousId;
                    }
                }

                $response = [
                    'success' => true,
                    'segments' => collect($segments),
                    'claim' => $checkExist->claim == 1,
                    'message' => $message,
                    'index'   => ($indexChoosen + 1),
                    'item_id' => $gifts[$indexChoosen]['id'],
                    'item_image' => $gifts[$indexChoosen]['gift_image'],
                    'item_value' => $gift_name,
                    'username' => $checkExist->name,
                    'code' => $input['code'],
                    'is_zonk' => $isZonk,
                    'whatsapp' => $whatsapp,
                    'item_description' => $message,
                ];

                CodeVoucherModel::where('id', $checkExist->id)->update(
                    [
                        'date_used' => date("Y-m-d H:i:s"),
                        'gift_name' => $gift_name
                    ]
                );
            } else {
                $response = [
                    'success' => false,
                    'used' => true,
                    'claim' => $checkExist->claim == 1,
                    'message' => 'Kode yang Anda masukkan telah digunakan, silahkan hubungi Admin untuk mendapatkan kode tiket baru, <a class="text-warning" href="' . $whatsapp . '">disini</a>!',
                    'index'    => null
                ];
            }
        } else {
            $response = [
                'success' => false,
                'message' => 'Kode yang Anda masukkan salah, silahkan hubungi Admin untuk mendapatkan kode tiket, <a class="text-warning" href="' . $whatsapp . '">disini</a>!',
                'index'    => null
            ];
        }


        return response()->json($response, 200);
    }

    function history()
    {

        if (!str_contains($_SERVER['SERVER_NAME'], "mystery-box") && $this->limitDomain) {
            return [];
        }

        $code_voucher = CodeVoucherModel::where('created_at', '!=', NULL)
            ->where('date_used', '!=', NULL)
            ->orderBy('created_at', 'DESC')
            ->limit(60)
            ->get();

        $list = [];

        foreach ($code_voucher as $key => $item) {

            $array_username = str_split(((isset($item->name) && $item->name != NULL) ? $item->name : ""), 3);

            $username = (isset($array_username[0]) ? $array_username[0] : "") . "*****";

            $gift_name = "";

            if ($item->gift == null) {
                $gift_name = $item->gift_name;
            }

            $list[] = [
                'no' => $key + 1,
                'username' => $username,
                'value' => $gift_name
            ];
        }

        return $list;
    }
}
