<?php

namespace App\Http\Controllers\Admin\Auth;

use App\Http\Controllers\Controller;
use App\Models\SettingModel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class LoginController extends Controller
{

    function index()
    {
        $title = "Selamat Datang di " . env('APP_NAME');

        $setting_list = SettingModel::all();

        foreach ($setting_list as $item) {
            $settings[$item->key] = $item->value;
        }

        return view('/pages/login', [
            'title' => $title,
            'settings' => $settings,
        ]);
    }

    function check(Request $request)
    {
        $request->validate([
            'email' => 'required|email:dns|max:255',
            'password' => 'required',
        ]);

        $remember_me = $request->has('remember_me') ? true : false;

        if (Auth::attempt(['email' => $request->input('email'), 'password' => $request->input('password')], $remember_me)) {

            $request->session()->regenerate();

            return redirect()->intended('/admin')->with('success', 'Login Berhasil !');
        }

        return back()->with('failed', 'Login Gagal, akun tidak ditemukan.');
    }

    function logout(Request $request)
    {
        Auth::logout();

        $request->session()->invalidate();

        $request->session()->regenerateToken();

        return redirect('/pages/login');
    }
}
