<?php

namespace App\Http\Controllers\Admin\Settings;

use App\Http\Controllers\Controller;
use App\Models\GiftModel;
use Ramsey\Uuid\Uuid;
use Illuminate\Http\Request;

class GiftController extends Controller
{

    function index()
    {
        $title = "Pengaturan Hadiah";

        $list = GiftModel::where('deleted_at', NULL)->orderBy('created_at')->get();

        return view('/pages/admin/settings/gifts/index', [
            'title' => $title,
            'list' => $list,
        ]);
    }

    function form()
    {
        $title = "Tambah Hadiah Spin Wheel";

        $defaultFontFamily = '"Lucida Console", "Courier New", monospace';

        return view('/pages/admin/settings/gifts/form', [
            'title' => $title,
            'defaultFontFamily' => $defaultFontFamily
        ]);
    }

    function edit($id)
    {
        $title = "Ubah Hadiah Spin Wheel";

        $detail = GiftModel::where('id', $id)->first();

        return view('/pages/admin/settings/gifts/form', [
            'title' => $title,
            'detail' => $detail,
        ]);
    }


    function create(Request $request) {

        $data = $request->all();

        $data['id'] = Uuid::uuid4()->toString();

        $file = $request->file('gift_image');

        if ($file != null) {
            $urlFile = $file->store('files');
            $data['gift_image'] = asset($urlFile);
        }

        GiftModel::create($data);

        $request->session()->flash('success', 'Berhasil menambah hadiah spin wheel!');

        return redirect('/admin/setting/gifts');
    }

    function update(Request $request) {

        $data = $request->all();

        $file = $request->file('gift_image');

        if ($file != null) {
            $urlFile = $file->store('files');
            $data['gift_image'] = asset($urlFile);
        }

        unset($data['_token']);

        GiftModel::where('id', $data['id'])->update($data);

        $request->session()->flash('success', 'Berhasil mengubah hadiah spin wheel!');

        return redirect('/admin/setting/gifts');
    }

    function delete($id) {

        GiftModel::where('id', $id)->update([
            'deleted_at' => date("Y-m-d H:i:s")
        ]);

        return redirect('/admin/setting/gifts');
    }
}
