<?php

use App\Http\Controllers\Admin\Auth\LoginController;
use App\Http\Controllers\Admin\CodeVoucher\CodeVoucherController;
use App\Http\Controllers\Admin\Staff\StaffController;
use App\Http\Controllers\Admin\Home\HomeController as AdminHomeController;
use App\Http\Controllers\Admin\Settings\MetatagController;
use App\Http\Controllers\Admin\Settings\AccountController;
use App\Http\Controllers\Admin\Settings\GiftController;
use App\Http\Controllers\Admin\Settings\ViewController;
use App\Http\Controllers\User\PlayerController;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Artisan;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

// Route::get('configuration', function () {
//     // $target = '/home/wheelpanen138/www.roda138.com/storage/app/files';
//     // $shortcut = '/home/wheelpanen138/public_html/roda138.com/files';
//     // symlink($target, $shortcut);
//     Artisan::call('storage:link');
//     // Artisan::call('migrate');
// });

// Route::get('/clear-cache', function () {
//     Artisan::call('cache:clear');
//     // return what you want
// });



Route::get('/', [PlayerController::class, 'login']);
Route::get('/play/{code}', [PlayerController::class, 'room']);
Route::get('/home', [AdminHomeController::class, 'index'])->middleware(['auth', 'admin']);
Route::post('/user/check', [PlayerController::class, 'check']);
Route::post('/game/select', [PlayerController::class, 'select']);
Route::get('/game/history', [PlayerController::class, 'history']);

Route::get('pages/login', [LoginController::class, 'index'])->name('login')->middleware('guest');

Route::group(['prefix' => 'admin'], function () {
    Route::get('/', [AdminHomeController::class, 'index'])->middleware(['auth', 'admin']);
    Route::get('/home', [AdminHomeController::class, 'index'])->middleware(['auth', 'admin']);
    Route::post('/login', [LoginController::class, 'check']);
    Route::post('/logout', [LoginController::class, 'logout']);

    Route::group(['prefix' => 'code-voucher'], function () {
        Route::get('/list', [CodeVoucherController::class, 'index'])->middleware(['auth', 'admin', 'access_rights']);
        Route::get('/list2', [CodeVoucherController::class, 'index2'])->middleware(['auth', 'admin', 'access_rights']);
        Route::get('/new', [CodeVoucherController::class, 'form'])->middleware(['auth', 'admin', 'access_rights']);
        Route::post('/create', [CodeVoucherController::class, 'create'])->middleware(['auth', 'admin', 'access_rights']);
        Route::get('/claim/{id}', [CodeVoucherController::class, 'claim'])->middleware(['auth', 'admin', 'access_rights']);
        Route::get('/delete/{id}', [CodeVoucherController::class, 'delete'])->middleware(['auth', 'admin', 'access_rights']);
    });

    Route::group(['prefix' => 'staff'], function () {
        Route::get('/list', [StaffController::class, 'index'])->middleware(['auth', 'admin', 'access_rights']);
        Route::get('/new', [StaffController::class, 'formNew'])->middleware(['auth', 'admin', 'access_rights']);
        Route::get('/edit/{id}', [StaffController::class, 'formEdit'])->middleware(['auth', 'admin', 'access_rights']);
        Route::post('/create', [StaffController::class, 'create'])->middleware(['auth', 'admin', 'access_rights']);
        Route::post('/update', [StaffController::class, 'update'])->middleware(['auth', 'admin', 'access_rights']);
        Route::get('/delete/{id}', [StaffController::class, 'delete'])->middleware(['auth', 'admin', 'access_rights']);
    });

    Route::group(['prefix' => 'setting'], function () {
        Route::group(['prefix' => 'gifts'], function () {
            Route::get('/', [GiftController::class, 'index'])->middleware(['auth', 'admin', 'access_rights']);
            Route::get('/new', [GiftController::class, 'form'])->middleware(['auth', 'admin', 'access_rights']);
            Route::get('/edit/{id}', [GiftController::class, 'edit'])->middleware(['auth', 'admin', 'access_rights']);
            Route::get('/delete/{id}', [GiftController::class, 'delete'])->middleware(['auth', 'admin', 'access_rights']);
            Route::post('/create', [GiftController::class, 'create'])->middleware(['auth', 'admin', 'access_rights']);
            Route::post('/update', [GiftController::class, 'update'])->middleware(['auth', 'admin', 'access_rights']);
        });

        Route::group(['prefix' => 'metatag'], function () {
            Route::get('/', [MetatagController::class, 'index'])->middleware(['auth', 'admin', 'access_rights']);
            Route::post('/save', [MetatagController::class, 'save'])->middleware(['auth', 'admin', 'access_rights']);
        });

        Route::group(['prefix' => 'account'], function () {
            Route::get('/', [AccountController::class, 'index'])->middleware(['auth', 'admin', 'access_rights']);
            Route::post('/save', [AccountController::class, 'save'])->middleware(['auth', 'admin', 'access_rights']);
        });

        Route::group(['prefix' => 'view'], function () {
            Route::get('/', [ViewController::class, 'index'])->middleware(['auth', 'admin', 'access_rights']);
            Route::get('/{key}', [ViewController::class, 'form'])->middleware(['auth', 'admin', 'access_rights']);
            Route::post('/save', [ViewController::class, 'save'])->middleware(['auth', 'admin', 'access_rights']);
            Route::get('/reset/{key}', [ViewController::class, 'reset'])->middleware(['auth', 'admin', 'access_rights']);
        });
    });
});
